@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::Pg;
 use Carp;
 
-our $VERSION = '1.3.1';
+our $VERSION = '1.1';
 our $Debug = 0;
 has pg => sub { +{} };
 
@@ -107,28 +107,13 @@ sub _quick_query {
     } else {
         # INSERT (default field name = id)
         if ($type eq 'INSERT') {
-        # get primary key from table
-        my $PK = 'id'; # default PK column is 'id'
+        # get primary key from table 
         my $pkey =  $self->pg->db->query(qq{SELECT a.attname FROM pg_index i JOIN pg_attribute a ON a.attrelid = i.indrelid
                                          AND a.attnum = ANY(i.indkey) WHERE  i.indrelid = '$table_name'::regclass AND i.indisprimary
-                                         ORDER BY a.attnum DESC});
-        # if id exists in PKeys get it, else - get last elem
-        while (my $next = $pkey->hash) {
-             if ( $next->{attname} eq 'id' ) {
-                $PK = $next->{attname};
-                # Note that "finish" needs to be called if you are not fetching all the possible rows
-                $pkey->finish;
-                last;
-             }
-             else {
-                $PK = $next->{attname};
-             }
-        }
-        
-        $sql .= ' returning ' . $PK;
-        
+                                         ORDER BY a.attnum DESC})->hash;
+        $sql .= ' returning ' . $pkey->{attname};
             eval {
-            return $self->pg->db->query($sql, @bind_params)->hash->{$PK};
+            return $self->pg->db->query($sql, @bind_params)->hash->{$pkey->{attname}};
             };
         } else {
         # delete/update
@@ -420,30 +405,6 @@ I<qcount>.
 my $one_row = $c->qselect('table_name', {id => 1},
                          { order_by => {desc => 'id'}, limit => 10, offset => 5, columns => qw[id name]});
 
-For more examples see /examples/*
-
-=head2 C<qinsert>
-
-For examples see /examples/* 
-
-=head2 C<qupdate>
-
-For examples see /examples/*
-
-=head2 C<qdelete>
-
-For examples see /examples/*
-
-=head2 C<qcustom>
-
-For examples see /examples/*
-
-=head2 C<qcount>
-
-For examples see /examples/* 
-
-=head2 C<qerror>
-
 For more examples see /examples/* 
 
 =head1 CONFIG
